@@ -3,7 +3,7 @@
 # Copyright 2022 Sxmo Contributors
 
 export WLR_RENDERER=pixman
-export SXMO_DISABLE_LEDS=1 #disable for now although N900 has leds, but paths are different
+export SXMO_LYSTI_LEDS=1
 export SXMO_POWER_BUTTON="0:0:twl_pwrbutton"
 export SXMO_SWAY_SCALE="1.5"
 #on N900 these two are swaped
@@ -13,3 +13,6 @@ export SXMO_ROTATE_DIRECTION="left"
 export SXMO_KEYBOARD_SLIDER_EVENT_DEVICE="/dev/input/by-path/platform-gpio_keys-event"
 export SXMO_KEYBOARD_SLIDER_CLOSE_EVENT="*code 10 (SW_KEYPAD_SLIDE), value 0*"
 export SXMO_KEYBOARD_SLIDER_OPEN_EVENT="*code 10 (SW_KEYPAD_SLIDE), value 1*"
+export SXMO_NO_KEYBOARD=1
+# modem is only supported via ofono, not modemmanager
+export SXMO_NO_MODEM=1
