@@ -14,10 +14,13 @@ isopen() {
 }
 
 open() {
+	if [ -n "$SXMO_NO_KEYBOARD" ]; then
+		return
+	fi
 	if [ -n "$KEYBOARD" ]; then
 		#Note: KEYBOARD_ARGS is not quoted by design as it may includes a pipe and further tools
 		# shellcheck disable=SC2086
-		isopen || eval "$KEYBOARD" $KEYBOARD_ARGS &
+		isopen || eval "$KEYBOARD" $KEYBOARD_ARGS >> "${XDG_STATE_HOME:-$HOME}"/sxmo.log 2>&1 &
 	fi
 }
 
