@@ -5,7 +5,7 @@
 # shellcheck source=configs/default_hooks/sxmo_hook_icons.sh
 . sxmo_hook_icons.sh
 # shellcheck source=scripts/core/sxmo_common.sh
-. "$(dirname "$0")/sxmo_common.sh"
+. sxmo_common.sh
 
 # on arch we manage mmsd with systemd instead of superd
 alias superctl='systemctl --user'
@@ -18,19 +18,13 @@ MMSCONFIG="$MMS_BASE_DIR/mms"
 defaultconfig() {
 	cat <<EOF
 [Modem Manager]
-CarrierMMSC=http://wholesale.mmsmvno.com/mms/wapenc
-MMS_APN=Ultra
+CarrierMMSC=http://mms.invalid
+MMS_APN=apn.invalid
 CarrierMMSProxy=NULL
 DefaultModemNumber=NULL
 AutoProcessOnConnection=true
 AutoProcessSMSWAP=true
-
-[Settings]
-UseDeliveryReports=false
-AutoCreateSMIL=false
-ForceCAres=false
-TotalMaxAttachmentSize=1100000
-MaxAttachments=25
+IMSI=invalid
 EOF
 }
 
