@@ -267,7 +267,7 @@ checkfornewtexts() {
 
 		fi
 
-		if grep -q screenoff "$SXMO_STATE"; then
+		if sxmo_state.sh get | grep -q screenoff; then
 			sxmo_state.sh set lock
 		fi
 
