@@ -69,6 +69,16 @@ toggleconnection() {
 	fi
 }
 
+togglegsm() {
+	if nmcli radio wwan | grep -q "enabled"; then
+			sxmo_notify_user.sh "Disabling GSM"
+			nmcli radio wwan off
+	else
+			sxmo_notify_user.sh "Enabling GSM"
+			nmcli radio wwan on
+	fi
+}
+
 deletenetworkmenu() {
 	CHOICE="$(
 		printf %b "$icon_cls Close Menu\n$(connections)" |
@@ -94,14 +104,14 @@ getifname() {
 addnetworkgsmmenu() {
 	CONNNAME="$(
 		echo "$icon_cls Close Menu" |
-			sxmo_dmenu_with_kb.sh -p "Alias"
+			sxmo_dmenu.sh -p "Alias"
 	)"
 	[ -z "$CONNNAME" ] && return
 	echo "$CONNNAME" | grep -q "Close Menu" && return
 
 	APN="$(
 		echo "$icon_cls Close Menu" |
-			sxmo_dmenu_with_kb.sh -p "APN"
+			sxmo_dmenu.sh -p "APN"
 	)"
 	[ -z "$APN" ] && return
 	echo "$APN" | grep -q "Close Menu" && return
@@ -133,7 +143,7 @@ addnetworkgsmmenu() {
 }
 
 addnetworkwpamenu() {
-	SSID="$(cat <<EOF | sxmo_dmenu_with_kb.sh -p "SSID"
+	SSID="$(cat <<EOF | sxmo_dmenu.sh -p "SSID"
 $icon_cls Close Menu
 $(nmcli d wifi list | tail -n +2 | grep -v '^\*' | awk -F'  ' '{ print $6 }' | grep -v '\-\-')
 EOF
@@ -141,7 +151,7 @@ EOF
 	[ -z "$SSID" ] && return
 	echo "$SSID" | grep -q "Close Menu" && return
 
-	PASSPHRASE="$(cat <<EOF | sxmo_dmenu_with_kb.sh -p "Passphrase"
+	PASSPHRASE="$(cat <<EOF | sxmo_dmenu.sh -p "Passphrase"
 $icon_cls Close Menu
 None
 EOF
@@ -160,7 +170,7 @@ EOF
 addhotspotusbmenu() {
 	CONNNAME="$(
 		echo "$icon_cls Close Menu" |
-			sxmo_dmenu_with_kb.sh -p "Alias"
+			sxmo_dmenu.sh -p "Alias"
 	)"
 	[ -z "$CONNNAME" ] && return
 	echo "$CONNNAME" | grep -q "Close Menu" && return
@@ -174,21 +184,21 @@ addhotspotusbmenu() {
 addhotspotwifimenu() {
 	SSID="$(
 		echo "$icon_cls Close Menu" |
-			sxmo_dmenu_with_kb.sh -p "SSID"
+			sxmo_dmenu.sh -p "SSID"
 	)"
 	[ -z "$SSID" ] && return
 	echo "$SSID" | grep -q "Close Menu" && return
 
 	key="$(
 		echo "$icon_cls Close Menu" |
-			sxmo_dmenu_with_kb.sh -p "Passphrase"
+			sxmo_dmenu.sh -p "Passphrase"
 	)"
 	[ -z "$key" ] && return
 	echo "$key" | grep -q "Close Menu" && return
 
 	key1="$(
 		echo "$icon_cls Close Menu" |
-			sxmo_dmenu_with_kb.sh -p "Confirm"
+			sxmo_dmenu.sh -p "Confirm"
 	)"
 	[ -z "$key1" ] && return
 	echo "$key1" | grep -q "Close Menu" && return
@@ -210,7 +220,7 @@ addhotspotwifimenu() {
 	fi
 
 	channel="$(
-		printf "%s Close Menu\n11\n" "$icon_cls" | sxmo_dmenu_with_kb.sh -p "Channel"
+		printf "%s Close Menu\n11\n" "$icon_cls" | sxmo_dmenu.sh -p "Channel"
 	)"
 	[ -z "$channel" ] && return
 	echo "$channel" | grep -q "Close Menu" && return
@@ -247,6 +257,13 @@ $(
 	fi
 )
 $icon_cfg Nmtui
+$(
+	if nmcli radio wwan | grep -q "enabled"; then
+			printf "%s Disable GSM\n" $icon_modem_disabled
+	else
+			printf "%s Enable GSM\n" $icon_modem_registered
+	fi
+)
 $icon_cfg Ifconfig
 $([ -z "$WIFI_ENABLED" ] || printf "%s Scan Wifi Networks\n" "$icon_wif")
 EOF
@@ -274,6 +291,9 @@ EOF
 			*"Nmtui" )
 				sxmo_terminal.sh nmtui || continue # Killeable
 				;;
+			*"Disable GSM"|*"Enable GSM" )
+				togglegsm
+				;;
 			*"Ifconfig" )
 				sxmo_terminal.sh watch -n 2 ifconfig || continue # Killeable
 				;;
