@@ -1,4 +1,6 @@
 #!/bin/sh
+# SPDX-License-Identifier: AGPL-3.0-only
+# Copyright 2022 Sxmo Contributors
 INPUT="$(cat)"
 STWIN="$(xprop -root | sed -n '/^_NET_ACTIVE_WINDOW/ s/.* //p')"
 
@@ -7,7 +9,7 @@ menu() {
 		printf %b "$(
 		echo "Close Menu";
 			echo "$INPUT" | grep -Eo '\S+' | tr -d '[:blank:]' | sort | uniq
-		)" | sxmo_dmenu_with_kb.sh -p "$PROMPT" -i
+		)" | sxmo_dmenu.sh -p "$PROMPT" -i
 	)"
 }
 
