@@ -1,18 +1,18 @@
 #!/bin/sh
-
+# SPDX-License-Identifier: AGPL-3.0-only
+# Copyright 2022 Sxmo Contributors
+# title="$icon_red Reddit"
 # include common definitions
 # shellcheck source=scripts/core/sxmo_common.sh
-. "$(dirname "$0")/sxmo_common.sh"
+. sxmo_common.sh
 
 [ -z "$SXMO_SUBREDDITS" ] && SXMO_SUBREDDITS="pine64official pinephoneofficial unixporn postmarketos linux"
 
 menu() {
-	sxmo_keyboard.sh open
 	SUBREDDIT="$(
 		printf %b "Close Menu\n$(echo "$SXMO_SUBREDDITS" | tr " " '\n')" |
 		sxmo_dmenu.sh -p "Subreddit:"
-	)"
-	sxmo_keyboard.sh close
+	)" || exit 0
 	[ "Close Menu" = "$SUBREDDIT" ] && exit 0
 
 	REDDITRESULTS="$(
@@ -23,19 +23,19 @@ menu() {
 			sed 's/===/\n/g' |
 			sed 's/^\t//g' |
 			sort -t"$(printf '%b' '\t')" -rnk4 |
-			awk -F'\t' '{ printf "↑%4s", $3; print " " $4 " " $1 " " $2 }'
+			awk -F'\t' '{ printf "%4s", $3; print " " $4 " " $1 " " $2 }'
 	)"
 
 	while true; do
 		RESULT="$(
 			printf %b "Close Menu\n$REDDITRESULTS" |
-			sxmo_dmenu.sh -fn Terminus-20
-		)"
+			sxmo_dmenu.sh
+		)" || exit 0
 
 		[ "Close Menu" = "$RESULT" ] && exit 0
 		URL=$(echo "$RESULT" | awk -F " " '{print $NF}')
 
-		sxmo_urlhandler.sh "$URL" fork
+		sxmo_urlhandler.sh "$URL"
 	done
 }
 
