@@ -1,11 +1,13 @@
 #!/bin/sh
+# SPDX-License-Identifier: AGPL-3.0-only
+# Copyright 2022 Sxmo Contributors
 
 # small utility to prompt user for PIN and unlock mode
 
 # shellcheck source=scripts/core/sxmo_common.sh
-. "$(which sxmo_common.sh)"
-# shellcheck source=scripts/core/sxmo_icons.sh
-. "$(which sxmo_icons.sh)"
+. sxmo_common.sh
+# shellcheck source=configs/default_hooks/sxmo_hook_icons.sh
+. sxmo_hook_icons.sh
 
 set -e
 
@@ -14,7 +16,7 @@ set -e
 
 while : ; do
 	PICKED="$(
-		cat <<EOF | sxmo_dmenu_with_kb.sh -l 3 -c -p "PIN:"
+		cat <<EOF | sxmo_dmenu.sh -l 3 -p "PIN:"
 $icon_cls Cancel
 0000
 1234
@@ -25,7 +27,7 @@ EOF
 			exit
 			;;
 		*)
-			SIM="$(mmcli -m any | grep -oE 'SIM\/([0-9]+)' | cut -d'/' -f2)"
+			SIM="$(mmcli -m any | grep -oE 'SIM\/([0-9]+)' | cut -d'/' -f2 | head -n1)"
 			MSG="$(mmcli -i "$SIM" --pin "$PICKED" 2>&1 || true)"
 			[ -n "$MSG" ] && sxmo_notify_user.sh "$MSG"
 			if printf "%s\n" "$MSG" | grep -q "not SIM-PIN locked"; then
