@@ -4,7 +4,7 @@
 
 # include common definitions
 # shellcheck source=scripts/core/sxmo_common.sh
-. "$(dirname "$0")/sxmo_common.sh"
+. sxmo_common.sh
 
 printf "Sxmo "
 cat "$(xdg_data_path sxmo/version)"
@@ -13,6 +13,11 @@ case "$SXMO_WM" in
 		/usr/bin/dwm -v
 		/usr/bin/dmenu -v
 		/usr/bin/st -v
+		if ! command -v bonsaictl > /dev/null; then
+			echo "no bonsai"
+		else
+			which bonsaictl
+		fi
 		;;
 	sway)
 		/usr/bin/sway -v
