@@ -43,7 +43,7 @@ processvvm() {
 			"VM: $VVM_SENDER_NAME ($VVM_ID)"
 	fi
 
-	if grep -q screenoff "$SXMO_STATE"; then
+	if sxmo_state.sh get | grep -q screenoff; then
 		sxmo_state.sh set lock
 	fi
 
