@@ -5,7 +5,7 @@
 # shellcheck source=configs/default_hooks/sxmo_hook_icons.sh
 . sxmo_hook_icons.sh
 # shellcheck source=scripts/core/sxmo_common.sh
-. "$(dirname "$0")/sxmo_common.sh"
+. sxmo_common.sh
 
 set -e
 
@@ -18,9 +18,9 @@ VVMCONFIG="$VVM_BASE_DIR/vvm"
 defaultconfig() {
 	cat <<EOF
 [Modem Manager]
-VVMEnabled=true
-VVMType=cvvm
-VVMDestinationNumber=127
+VVMEnabled=false
+VVMType=type_invalid
+VVMDestinationNumber=number_invalid
 EOF
 }
 
