@@ -73,7 +73,7 @@ swayinputevent() {
 
 	# If we dont have any matching input
 	if ! swaymsg -t get_inputs \
-		| gojq -r ".[] | select(.type == \"$TOUCH_POINTER_ID\" )" \
+		| jq -r ".[] | select(.type == \"$TOUCH_POINTER_ID\" )" \
 		| grep -q .; then
 
 		if [ -z "$2" ]; then
@@ -112,27 +112,20 @@ xorgfocusedwindow() {
 }
 
 swayfocusedwindow() {
-	TREE="$(swaymsg -t get_tree)"
-	FOCUS="$(
-		printf %s "$TREE" | jq -r '
-			recurse(.nodes[]) |
-			select((.focused == true) and (.app_id != null)) |
-			{app_id: .app_id, name: .name} |
-			"app: " + .app_id, "title: " + .name
-		'
-	)"
-	if [ -z "$FOCUS" ]; then
-		#app_id is null, fall back to detect xwayland app:
-		FOCUS="$(
-			printf %s "$TREE" | jq -r '
-				recurse(.nodes[]) |
-				select((.focused == true) and (.shell == "xwayland")) |
-				{app_id: .window_properties.class, name: .window_properties.title} |
-				"app: " + .app_id, "title: " + .name
-			'
-		)"
-	fi
-	printf "%s\n" "$FOCUS"
+	swaymsg -t get_tree | jq -r '
+		recurse(.nodes[]) |
+		select(.focused == true) |
+		{
+			app_id: (if .app_id != null then
+					.app_id
+				else
+					.window_properties.class
+				end),
+			name: .name,
+		} |
+		select(.app_id != null and .name != null) |
+		"app: " + .app_id, "title: " + .name
+	'
 }
 
 swaypaste() {
@@ -151,7 +144,7 @@ swayexec() {
 swayexecwait() {
 	PIDFILE="$(mktemp)"
 	printf '"%s" & printf %%s "$!" > "%s"' "$*" "$PIDFILE" \
-		| xargs -I{} swaymsg exec -- sh -c '{}'
+		| xargs -I{} swaymsg exec -- '{}'
 	while : ; do
 		sleep 0.5
 		kill -0 "$(cat "$PIDFILE")" 2> /dev/null || break
