@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 7420272b1237bc2bc8ba3fe84c18b0a4
+# configversion: a2237491eb98bd6f974085f0a802d08c
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 # shellcheck disable=SC2154
@@ -23,7 +23,9 @@ write_line_app() {
 
 write_line_app gnome-2048 "$icon_gam 2048" "gnome-2048"
 write_line_app jami-qt "$icon_msg Jami" "jami-qt"
+[ -n "$PLAN9" ] && write_line_app acme "$icon_edt Acme" "acme -c 1 -f $PLAN9/font/pelm/ascii.16.font"
 write_line_app aerc "$icon_eml Aerc" "sxmo_terminal.sh aerc"
+write_line_app alacritty "$icon_trm Alacritty" "alacritty"
 write_line_app amberol "$icon_mus Amberol" "amberol $XDG_MUSIC_DIR"
 write_line_app amfora "$icon_glb Amfora" "sxmo_terminal.sh amfora"
 write_line_app animatch "$icon_gam Animatch" "animatch"
@@ -53,6 +55,7 @@ write_line_app foliate "$icon_bok Foliate" "foliate"
 ( [ "$SXMO_WM" = sway ] && command -v foot >/dev/null) && \
 	write_line "$icon_trm Foot" "foot $SHELL"
 write_line_app foxtrotgps "$icon_gps Foxtrotgps" "foxtrotgps"
+write_line_app fractal "$icon_msg Fractal" "fractal"
 write_line_app g4music "$icon_mus G4Music" "g4music"
 write_line_app geany "$icon_eml Geany" "geany"
 write_line_app geary "$icon_eml Geary" "geary"
@@ -68,6 +71,7 @@ write_line_app gpodder "$icon_rss gPodder" "gpodder"
 write_line_app gucharmap "$icon_inf Gucharmap" "gucharmap"
 write_line_app hexchat "$icon_msg Hexchat" "hexchat"
 write_line_app htop "$icon_cfg Htop" "sxmo_terminal.sh htop"
+write_line_app iamb "$icon_msg Iamb" "sxmo_terminal.sh iamb"
 write_line_app irssi "$icon_msg Irssi" "sxmo_terminal.sh irssi"
 write_line_app ii "$icon_msg Ii" "sxmo_terminal.sh ii"
 write_line_app ipython "$icon_trm IPython" "sxmo_terminal.sh ipython"
@@ -77,6 +81,7 @@ write_line_app komikku "$icon_bok Komikku" "komikku"
 write_line_app kontact "$icon_msg Kontact" "kontact"
 write_line_app konversation "$icon_msg Konversation" "konversation"
 write_line_app koreader "$icon_bok KOReader" "koreader"
+write_line_app krita "$icon_img Krita" "krita --nosplash"
 write_line_app kwrite "$icon_edt Kwrite" "kwrite"
 write_line_app lagrange "$icon_glb Lagrange" "lagrange"
 write_line_app lf "$icon_dir Lf" "sxmo_terminal.sh lf"
@@ -87,6 +92,7 @@ write_line_app marble "$icon_map Marble" "marble"
 write_line_app gnome-maps "$icon_map Maps" "gnome-maps"
 write_line_app micro "$icon_edt Micro" "sxmo_terminal.sh micro"
 write_line_app midori "$icon_glb Midori" "midori"
+write_line_app moment "$icon_msg Moment" "moment"
 write_line_app mutt "$icon_eml Mutt" "sxmo_terminal.sh mutt"
 write_line_app mumble "$icon_grp Mumble" mumble
 write_line_app nano "$icon_edt Nano" "sxmo_terminal.sh nano"
@@ -123,6 +129,7 @@ write_line_app telegram-desktop "$icon_tgm Telegram" "telegram-desktop"
 write_line_app termite "$icon_trm Termite" "termite -e $SHELL"
 write_line_app thunar "$icon_dir Thunar" "sxmo_terminal.sh thunar"
 write_line_app thunderbird "$icon_eml Thunderbird" "thunderbird"
+write_line_app tilix "$icon_trm Tilix" "tilix"
 write_line_app com.github.bleakgrey.tootle "$icon_msg Tootle" "com.github.bleakgrey.tootle"
 write_line_app re.sonny.Tangram "$icon_glb Tangram" "re.sonny.Tangram"
 write_line_app totem "$icon_mvi Totem" "totem"
