@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: d7a31b6b01150a2b1ad3e57f556a5de6
+# configversion: 05a62926ecbebf5cad4dd0990b982ec6
 
 load_data() {
 	data="$(upower -i "$1" | grep . | sed -e 's|^ \+||' -e 's|: \+|:|')"
@@ -10,6 +10,8 @@ data_get() {
 	printf "%b" "$data" | grep "^$1:" | cut -d: -f2
 }
 
+SETTED_LED_PATH="$XDG_RUNTIME_DIR/sxmo_hook_battery_setted_led"
+
 device_changed() {
 	name="$(data_get "native-path")"
 	state="$(data_get "state")"
@@ -23,6 +25,14 @@ device_changed() {
 		return
 	fi
 
+	if [ "$percentage" -lt 25 ] && [ ! -f "$SETTED_LED_PATH" ]; then
+		touch "$SETTED_LED_PATH"
+		sxmo_led.sh set red 100
+	elif [ -f "$SETTED_LED_PATH" ]; then
+		rm "$SETTED_LED_PATH"
+		sxmo_led.sh set red 0
+	fi
+
 	sxmo_hook_statusbar.sh battery "$name" "$state" "$percentage"
 }
 
