@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 0a2402a485244d818a413065a1c82b4f
+# configversion: 77418ea2060a6e8d593dc9015b12c58d
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -78,8 +78,8 @@ case "$WMCLASS" in
 			) ^ 1 ^ supertoggle_daemon 'sxmo_hook_lisgd' && (rm $XDG_CACHE_HOME/sxmo/sxmo.nogesture 2>/dev/null || touch $XDG_CACHE_HOME/sxmo/sxmo.nogesture)
 			$icon_cfg Toggle Bar ^ 0 ^ sxmo_wm.sh togglebar
 			$icon_bth Bluetooth $(
-				rfkill list bluetooth | grep -q "yes" &&
-				printf %b "$icon_tof" ||  printf %b "$icon_ton";
+				rfkill list bluetooth -no ID,SOFT,HARD | grep -vq " blocked" &&
+				printf %b "$icon_ton" ||  printf %b "$icon_tof";
 				printf %b "^ 1 ^ doas sxmo_bluetoothtoggle.sh && sxmo_hook_statusbar.sh bluetooth"
 			)
 			$(test "$SXMO_WM" = dwm && printf %b "$icon_cfg Invert Colors ^ 1 ^ xcalib -a -invert")
@@ -105,6 +105,7 @@ case "$WMCLASS" in
 			$icon_cfg Edit configuration         ^ 0 ^ sxmo_terminal.sh $EDITOR $XDG_CONFIG_HOME/sxmo/$(test "$SXMO_WM" = sway && printf sway || printf xinit)
 			$(command -v pmos-tweaks >/dev/null && echo "$icon_cfg PostmarketOS Tweaks	     ^ 0 ^ GDK_SCALE=1 pmos-tweaks")
 			$icon_cfg Suspend Blockers           ^ 0 ^ sxmo_terminal.sh sxmo_debug_suspend.sh
+			$icon_inf Log                        ^ 0 ^ sxmo_terminal.sh tail -n 100 -f ${XDG_STATE_HOME:-$HOME}/sxmo.log
 			$icon_inf Version                    ^ 0 ^ sxmo_terminal.sh sxmo_version.sh --block
 		"
 		WINNAME=Config
@@ -217,9 +218,18 @@ case "$WMCLASS" in
 		WINNAME=St
 		;;
 	*foot*|*st*|*terminal*|org.gnome.vte.application|*alacritty*)
-		# First we try to handle the app running inside the terminal:
 		WMNAME="${1:-$(printf %s "$XPROPOUT" | grep title: | cut -d" " -f2- | tr '[:upper:]' '[:lower:]')}"
-		if printf %s "$WMNAME" | grep -qi -E -w "(vi|vim|vis|nvim|neovim|kakoune)"; then
+
+		# These git commands only launch the editor.
+		case "$WMNAME" in
+			*"git add"*|*"git bugreport"*|*"git commit"*|*"git merge"*|*"git notes"*|*"git rebase"*|*"git replace"*|*"git send-email"*|*"git svn"*)
+				WMNAME="$WMCLASS $EDITOR"
+				;;
+		esac
+
+		# First we try to handle the app running inside the terminal:
+		case " $WMNAME " in
+		*" vi "*|*" vim "*|*" vis "*|*" nvim "*|*neovim*|*kakoune*)
 			#Vim in foot
 			CHOICES="
 				$icon_cls Save and Quit    ^ 0 ^ sxmo_type -k Escape -s 300 ':wq' -k Return
@@ -238,7 +248,8 @@ case "$WMCLASS" in
 				$icon_mnu Terminal menu    ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
 			WINNAME=Vim
-		elif printf %s "$WMNAME" | grep -qi -w "nano"; then
+			;;
+		*nano*)
 			#Nano in foot
 			CHOICES="
 				$icon_aru Scroll up       ^ 1 ^ sxmo_type -k Prior
@@ -253,7 +264,8 @@ case "$WMCLASS" in
 				$icon_mnu Terminal menu   ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
 			WINNAME=Nano
-		elif printf %s "$WMNAME" | grep -qi -w "micro"; then
+			;;
+		*micro*)
 			#Micro
 			CHOICES="
 				$icon_aru Scroll up       ^ 1 ^ sxmo_type -k Prior
@@ -271,7 +283,8 @@ case "$WMCLASS" in
 				$icon_mnu Terminal menu   ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
 			WINNAME=Micro
-		elif printf %s "$WMNAME" | grep -qi -w "tuir"; then
+			;;
+		*tuir*)
 			#tuir (reddit client) in foot
 			CHOICES="
 				$icon_aru Previous      ^ 1 ^ sxmo_type k
@@ -289,7 +302,8 @@ case "$WMCLASS" in
 				$icon_mnu Terminal menu ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
 			WINNAME=tuir
-		elif printf %s "$WMNAME" | grep -qi -w "w3m"; then
+			;;
+		*w3m*)
 			#w3m
 			CHOICES="
 				$icon_arl Back          ^ 1 ^ sxmo_type b
@@ -305,7 +319,8 @@ case "$WMCLASS" in
 				$icon_mnu Terminal menu   ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
 			WINNAME=w3m
-		elif printf %s "$WMNAME" | grep -qi -w "ncmpcpp"; then
+			;;
+		*ncmpcpp*)
 			#ncmpcpp
 			CHOICES="
 				$icon_lst Playlist        ^ 0 ^ sxmo_type 1
@@ -321,7 +336,8 @@ case "$WMCLASS" in
 				$icon_mnu Terminal menu   ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
 			WINNAME=ncmpcpp
-		elif printf %s "$WMNAME" | grep -qi -w "aerc"; then
+			;;
+		*aerc*)
 			#aerc
 			CHOICES="
 				$icon_pau Archive	  ^ 1 ^ sxmo_type ':archive flat' -k Return
@@ -332,7 +348,8 @@ case "$WMCLASS" in
 				$icon_trm xdg-open Part	  ^ 0 ^ sxmo_type ':open' -k Return
 			"
 			WINNAME=aerc
-		elif printf %s "$WMNAME" | grep -qi -E -w "(less|mless)"; then
+			;;
+		*less*|*"git blame"*|*"git diff"*|*"git grep"*|*"git help"*|*"git log"*|*"git stash"*|*"git tag"*|*"git var"*)
 			#less
 			CHOICES="
 				$icon_arr Page next       ^ 1 ^ sxmo_type ':n' -k Return
@@ -345,13 +362,8 @@ case "$WMCLASS" in
 				$icon_mnu Terminal menu ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
 			WINNAME=less
-		elif printf %s "$WMNAME" | grep -qi -w "git \(blame\|diff\|grep\|help\|log\|stash\|tag\|var\)"; then
-			# These git commands only launch the pager.
-			exec "$0" "$WMCLASS ${PAGER:-less}"
-		elif printf %s "$WMNAME" | grep -qi -w "git \(add\|bugreport\|commit\|merge\|notes\|rebase\|replace\|send-email\|svn\)"; then
-			# These git commands only launch the editor.
-			exec "$0" "$WMCLASS $EDITOR"
-		elif printf %s "$WMNAME" | grep -qi -w "git"; then
+			;;
+		*git*)
 			# git am, branch, config, tag (and other commands which launch both).
 			CHOICES="
 				$icon_fil ${PAGER:-less} menu ^ 0 ^ sxmo_appmenu.sh '$WMCLASS ${PAGER:-less}'
@@ -359,7 +371,8 @@ case "$WMCLASS" in
 				$icon_mnu Terminal menu ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
 			WINNAME=git
-		elif printf %s "$WMNAME" | grep -qi -w "senpai"; then
+			;;
+		*senpai*)
 			CHOICES="
 				$icon_aru Scroll up       ^ 1 ^ sxmo_type -k Prior
 				$icon_ard Scroll down     ^ 1 ^ sxmo_type -k Next
@@ -369,7 +382,8 @@ case "$WMCLASS" in
 				$icon_usr Toggle Members  ^ 0 ^ sxmo_type -k F8
 			"
 			WINNAME=senpai
-		elif printf %s "$WMNAME" | grep -qi -w "weechat"; then
+			;;
+		*weechat*)
 			#weechat
 			CHOICES="
 				$icon_msg Hotlist Next            ^ 1 ^ sxmo_type -M Alt a
@@ -381,7 +395,8 @@ case "$WMCLASS" in
 				$icon_mnu Terminal menu ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
 			WINNAME=weechat
-		elif printf %s "$WMNAME" | grep -qi -w "sms\|missed call"; then
+			;;
+		*" sms "*|*"missed call"*)
 			number="$(printf "%s\n" "$WMNAME" | xargs -0 pnc find | tr -d '\n')"
 			#sms
 			CHOICES="
@@ -406,7 +421,8 @@ case "$WMCLASS" in
 				$icon_mnu Terminal menu ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
 			WINNAME=phone
-		elif printf %s "$WMNAME" | grep -qi -w "cmus"; then
+			;;
+		*cmus*)
 			# cmus
 			# requires `:set set_term_title=false` in cmus to match the application
 			CHOICES="
@@ -420,7 +436,27 @@ case "$WMCLASS" in
 				$icon_mnu Terminal menu   ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
 			WINNAME=cmus
-		else
+			;;
+		*iamb*)
+			CHOICES="
+				$icon_aru Page Up          ^ 1 ^ sxmo_type.sh -k Escape -M Ctrl -k b
+				$icon_tab Toggle Selection ^ 0 ^ sxmo_type.sh -k Escape -M Ctrl -k W m
+				$icon_ard Page Down        ^ 1 ^ sxmo_type.sh -k Escape -M Ctrl -k f
+				$icon_ret Reply To Message ^ 0 ^ sxmo_type.sh -k Escape :reply -k Return
+				$icon_tab New Tab          ^ 0 ^ sxmo_type.sh -k Escape :tab rooms -k Return
+				$icon_arl Previous Tab     ^ 0 ^ sxmo_type.sh -k Escape :tabp -k Return
+				$icon_arr Next Tab         ^ 0 ^ sxmo_type.sh -k Escape :tabn -k Return
+				$icon_cls Close Tab        ^ 0 ^ sxmo_type.sh -k Escape :tabclose -k Return
+				$icon_win Split View       ^ 0 ^ sxmo_type.sh -k Escape :split -k Return
+				$icon_win Split View Vertical ^ 0 ^ sxmo_type.sh -k Escape :vsplit -k Return
+				$icon_msg Direct Messages  ^ 0 ^ sxmo_type.sh -k Escape :dms -k Return
+				$icon_grp Rooms            ^ 0 ^ sxmo_type.sh -k Escape :rooms -k Return
+				$icon_glb Spaces           ^ 0 ^ sxmo_type.sh -k Escape :spaces -k Return
+				$icon_sav Download         ^ 0 ^ sxmo_type.sh -k Escape :download -k Return
+			"
+			WINNAME=iamb
+			;;
+		*)
 			# Now we fallback to the default terminal menu
 			case "$WMCLASS" in
 				*st*)
@@ -482,8 +518,8 @@ case "$WMCLASS" in
 					WINNAME=Alacritty
 					;;
 			esac
-		fi
-	;;
+		esac
+		;;
 	*okular*)
 		# Okular
 		CHOICES="
@@ -597,9 +633,26 @@ case "$WMCLASS" in
 		"
 		WINNAME=Firefox
 		;;
+	*krita*)
+		# Krita
+		CHOICES="
+			$icon_fnd Open                   ^ 0 ^ sxmo_type -M Ctrl o
+			$icon_sav Save                   ^ 0 ^ sxmo_type -M Ctrl s
+			$icon_pst Paste                  ^ 0 ^ sxmo_type -M Ctrl v
+			$icon_del Delete                 ^ 0 ^ sxmo_type -k Delete
+			$icon_win Select                 ^ 0 ^ sxmo_type -M Ctrl r
+			$icon_modem_disabled Deselect    ^ 0 ^ sxmo_type -M Ctrl -M Shift a
+			$icon_wn2 Crop                   ^ 0 ^ sxmo_type c
+			$icon_flt Fill                   ^ 0 ^ sxmo_type f
+			$icon_modem_connected Gradient   ^ 0 ^ sxmo_type g
+			$icon_dof HSV Adjust    	     ^ 0 ^ sxmo_type -M Ctrl u
+			$icon_cls Close Image        	 ^ 0 ^ sxmo_type -M Ctrl w
+		"
+		WINNAME=Krita
+		;;
 	*vimb*)
 		CHOICES="
-			$icon_glb Navigate        ^ 0 ^ sxmo_type -k Escape o && sxmo_keyboard.sh open
+			$icon_glb Navigate        ^ 0 ^ sxmo_type -k Escape o
 			$icon_zmi Zoom            ^ 1 ^ sxmo_type -k Escape zi
 			$icon_zmo Zoom            ^ 1 ^ sxmo_type -k Escape zo
 			$icon_arl History         ^ 1 ^ sxmo_type -M Ctrl o
@@ -616,12 +669,12 @@ case "$WMCLASS" in
 			$icon_cls Close Tab          ^ 0 ^ sxmo_type -M Ctrl w
 			$icon_bok Open Bookmarks     ^ 0 ^ sxmo_type -M Ctrl b
 			$icon_pls Add Bookmark       ^ 0 ^ sxmo_type -M Ctrl d
-			$icon_edt Edit Bookmarks     ^ 0 ^ sxmo_keyboard.sh open && sxmo_terminal.sh $EDITOR ~/.local/share/geopard/bookmarks.gemini
+			$icon_edt Edit Bookmarks     ^ 0 ^ sxmo_terminal.sh $EDITOR ~/.local/share/geopard/bookmarks.gemini
 			$icon_zmi Increase Font Size ^ 1 ^ sxmo_type -M Ctrl -k plus
 			$icon_zmo Decrease Font Size ^ 1 ^ sxmo_type -M Ctrl -k minus
 			$icon_arl History Back       ^ 1 ^ sxmo_type -M Alt -k Left
 			$icon_arr History Forward    ^ 1 ^ sxmo_type -M Alt -k Right
-			$icon_fnd URL Bar            ^ 0 ^ sxmo_keyboard.sh open && sxmo_type -k F6
+			$icon_fnd URL Bar            ^ 0 ^ sxmo_type -k F6
 			$icon_rld Refresh            ^ 0 ^ sxmo_type -k F6 -k Return
 			"
 		WINNAME=Geopard
@@ -647,7 +700,7 @@ case "$WMCLASS" in
 		$icon_zmi Zoom in ^ 1 ^ sxmo_type -M ctrl =
 		$icon_zmo Zoom out ^ 1 ^ sxmo_type -M ctrl -k minus
 		$icon_fnd Explore POI ^ 0 ^ sxmo_type -M ctrl -M Shift F
-		$icon_fnd Search ^ 0 ^ sxmo_type -M ctrl f  && sxmo_keyboard.sh open
+		$icon_fnd Search ^ 0 ^ sxmo_type -M ctrl f
 		$icon_lst Show last results ^ 0 ^ sxmo_type -M ctrl r
 		$icon_map Toggle route planner ^ 0 ^ sxmo_type -M ctrl d
 		$icon_gps Show current location ^ 0 ^ sxmo_type -M ctrl l
@@ -672,6 +725,38 @@ case "$WMCLASS" in
 		"
 		WINNAME=Maps
 		;;
+	*badwolf*)
+		# Badwolf Browser
+		CHOICES="
+			$icon_tab New Tab           ^ 0 ^ sxmo_type -M Ctrl -k t
+			$icon_cls Close Tab         ^ 0 ^ sxmo_type -M Alt -k d
+			$icon_fnd Reset Zoom^ 0 ^ sxmo_type -M Ctrl -k 0
+			$icon_arr History        ^ 1 ^ sxmo_type -M Ctrl ]
+			$icon_arl History        ^ 1 ^ sxmo_type -M Ctrl [
+			$icon_arr Next Tab          ^ 1 ^ sxmo_type -M Alt -k Right
+			$icon_arl Previous Tab      ^ 1 ^ sxmo_type -M Alt -k Left
+			$icon_rld Refresh     ^ 0 ^ sxmo_type -M Shift -M Ctrl -k r
+			$icon_fnd Search     ^ 0 ^ sxmo_type -M Shift -M Ctrl -k f
+			$icon_arr Next (Search)     ^ 0 ^ sxmo_type -M Shift -M Ctrl -k g
+			$icon_arl Previous (Search)     ^ 0 ^ sxmo_type -M Shift -M Ctrl -M Shift -k g
+			$icon_flt URL Bar     ^ 0 ^ sxmo_type -M Shift -M Ctrl l
+			$icon_fnd Open Web Inspector      ^ 0 ^ sxmo_type -k F12
+		"
+		WINNAME=Badwolf
+		;;
+	*acme*)
+		# Acme
+		CHOICES="
+			$icon_mse 2 (Right) [2s delay]  ^ 0 ^ sleep 2 && xdotool click 3
+			$icon_mse 3 (Middle) [2s delay]  ^ 0 ^ sleep 2 && xdotool click 2
+			$icon_itm Autocomplete            ^ 0 ^ sxmo_type.sh -M Ctrl -k f
+			$icon_exp Select Last Typed Text  ^ 0 ^ sxmo_type.sh -M Escape
+			$icon_del Delete To Start Of Line       ^ 0 ^ sxmo_type.sh -M Ctrl -k U
+			$icon_arl Move To Start Of Line   ^ 0 ^ sxmo_type.sh -M Ctrl -k A
+			$icon_arr Move To End Of Line      ^ 0 ^ sxmo_type.sh -M Ctrl -k E
+		"
+		WINNAME=Acme
+		;;
 	*)
 		# Default system menu (no matches)
 		CHOICES="
@@ -683,15 +768,15 @@ case "$WMCLASS" in
 			$icon_msg Texts                                              ^ 0 ^ sxmo_modemtext.sh
 			$icon_usr Contacts                                           ^ 0 ^ sxmo_contactmenu.sh
 			$(
-				rfkill list bluetooth | grep -q "yes" ||
+				rfkill list bluetooth -no ID,SOFT,HARD | grep -vq " blocked" &&
 				printf %b "$icon_bth Bluetooth ^ 1 ^ sxmo_bluetoothmenu.sh"
 			)
 			$(command -v megapixels >/dev/null && echo "$icon_cam Camera ^ 0 ^ GDK_SCALE=2 megapixels")
 			$(
-				if [ -z "$SXMO_DISABLE_LEDS" ]; then
+				if brightness="$(brightnessctl -d "white:flash" get)"; then
 					printf "%s Flashlight " "$icon_fll"
-					sxmo_led.sh get white | grep -vq ^100$ &&
-						printf %b "$icon_tof" ||  printf %b "$icon_ton";
+					[ "$brightness" -gt 0 ] &&
+						printf %b "$icon_ton" ||  printf %b "$icon_tof";
 					printf %b "^ 1 ^ sxmo_flashtoggle.sh"
 				fi
 			)
