@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: b4c50b1494528d1671fc7c807ab4aafa
+# configversion: 1afeceeb9991cd40646f9dc14d3697dc
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -40,7 +40,7 @@ icon_clk="󰥔"
 icon_cls="󰅖" #close
 icon_com="" # (Laptop) Computer (💻)
 icon_cpy=""
-icon_del="󰅖" #delete
+icon_del="" #delete
 icon_dir="" #directory folder
 icon_dof="" # dot off
 icon_don="" # dot on
@@ -58,7 +58,7 @@ icon_fil="" #file
 icon_flk="" #falkon
 icon_fll="󰉄" #flashlight
 icon_flt="" #filter/pipe
-icon_fnd="" #search/find
+icon_fnd="󰍉" #search/find
 icon_gam="󰊴" # gaming controller (🎮)
 icon_glb="" #globe
 icon_gps='' #gps
@@ -66,6 +66,7 @@ icon_grd="󰀻"
 icon_grp="" #group
 icon_hdp="" #headphones
 icon_hom=""
+icon_hst="󰋎" #headset🗣️
 icon_img="󰏜"
 icon_inf="" #info
 icon_itm="" #item (default)
@@ -136,8 +137,8 @@ icon_wn2=""
 icon_wrh=""
 icon_wtr="" #weather
 icon_ytb="" #youtube
-icon_zmi=""
-icon_zmo=""
+icon_zmi="󰛭" # Zoom in/magnify
+icon_zmo="󰛬" # Zoom out/demagnify
 icon_zzz="" #sleep/suspend/crust
 
 # modem states
