@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 6547d89cee221bcd21a4724f3a2e268f
+# configversion: ab967cbbcb9e9cc4d49895887151243f
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 #
@@ -23,7 +23,10 @@ sxmo_led.sh blink red blue &
 sxmo_wm.sh dpms on
 sxmo_wm.sh inputevent touchscreen off
 
-sxmo_jobs.sh start periodic_blink sxmo_run_periodically.sh - 2 sxmo_led.sh blink red blue
+if [ ! -e "$XDG_CACHE_HOME"/sxmo/sxmo.nosuspend ]; then
+	sxmo_jobs.sh start periodic_blink \
+		sxmo_run_periodically.sh -w 2 -- sxmo_led.sh blink red blue
+fi
 
 case "$SXMO_WM" in
 	dwm)
