@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 72930bc53d64a3cce0338cf500d019a0
+# configversion: 137776b7c0e0be4cc27ea62fa6511a3f
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -21,11 +21,13 @@
 if ! sxmo_modemcall.sh list_active_calls | grep -q active; then
 
 	if [ ! -f "$XDG_CONFIG_HOME"/sxmo/.noring ]; then
-		mpv --no-resume-playback --quiet --no-video "$SXMO_TEXTSOUND" >> /dev/null 2>&1
+		mpv --no-resume-playback --quiet --no-video "$SXMO_TEXTSOUND" >> /dev/null 2>&1 &
 	fi
 
 	if [ ! -f "$XDG_CONFIG_HOME"/sxmo/.novibrate ]; then
-		sxmo_vibrate 500
+		sxmo_vibrate 500 "${SXMO_VIBRATE_STRENGTH:-1}" &
 	fi
 
+	wait
+
 fi
